# YouTube-Driver
This package provides a high-level abstraction over selenium to allow programmatic interaction with YouTube's interface.

## Installation
1. Install the package using `pip install --upgrade YouTube-Driver`.
2. Download [youtube-dl](https://youtube-dl.org/) to a location in your PATH.
3. Download the corresponding webdriver for your browser to a location in your PATH.
    - For Google Chrome: [chromedriver](https://chromedriver.chromium.org/downloads)
    - For Firefox: [geckodriver](https://github.com/mozilla/geckodriver/releases)

## Getting Started
- See [`example.py`](https://github.com/ucdavis-noyce/YouTube-Driver/blob/main/src/ytdriver/example.py) for a quick overview on how to use the package.
- Read the [documentation](https://ucdavis-noyce.github.io/YouTube-Driver/ytdriver).

## Acknowledgements
This tool was developed as part of an effort by researchers at UC Davis to audit the recommendations on YouTube. Read more about it [here](https://youtubeaudit.com).

The primary maintainer is [Muhammad Haroon](https://github.com/haroon96).
